CaptionLayoutEntity class

Constructors

CaptionLayoutEntity({String layoutDirection = 'row', CaptionEntity? mainCaption, CaptionEntity? subCaption})
const
CaptionLayoutEntity.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isFilled → bool
no setter
layoutDirection → String
final
mainCaption → CaptionEntity?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subCaption → CaptionEntity?
final

Methods

copy() → CaptionLayoutEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited