ColumnEntity class

Constructors

ColumnEntity({bool primaryKey = false, bool autoIncrease = false, String? name, String title = '', String type = 'string', String? format, String description = '', bool display = true, bool editable = true, double widthFactor = 0.2, InputDecorationEntity? inputDecoration, ConstrainsEntity? constrains, StyleEntity? style})
const
ColumnEntity.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

autoIncrease → bool
final
constrains → ConstrainsEntity?
final
description → String
final
display → bool
final
editable → bool
final
format → String?
final
hashCode → int
The hash code for this object.
no setterinherited
inputDecoration → InputDecorationEntity?
final
name → String?
final
primaryKey → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → StyleEntity?
final
title → String
final
type → String
final
widthFactor → double
final

Methods

copy() → ColumnEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited