ConstrainsEntity class

Constructors

ConstrainsEntity({bool? required, int? minimum, int? maximum})
const
ConstrainsEntity.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximum → int?
final
minimum → int?
final
required → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → ConstrainsEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited