FooterEntity class

Constructors

FooterEntity({String? title, bool display = true, bool editable = true, InputDecorationEntity? inputDecoration, ConstrainsEntity? constrains, StyleEntity? style})
FooterEntity.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

constrains → ConstrainsEntity?
final
display → bool
final
editable → bool
final
hashCode → int
The hash code for this object.
no setterinherited
inputDecoration → InputDecorationEntity?
final
isFilled → bool
no setter
required → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → StyleEntity?
final
title ↔ String?
getter/setter pair

Methods

copy() → FooterEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited