FooterLayoutEntity class

Constructors

FooterLayoutEntity({String layoutDirection = 'row', List<FooterEntity>? footerContent})
const
FooterLayoutEntity.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

footerContent → List<FooterEntity>?
final
hashCode → int
The hash code for this object.
no setterinherited
isFilled → bool
no setter
layoutDirection → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → FooterLayoutEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited