InputDecorationEntity class

Constructors

InputDecorationEntity({int? minLines, int? maxLines, int? maxLength, String? hintText, Color? fillColor})
const
InputDecorationEntity.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

fillColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
maxLength → int?
final
maxLines → int?
final
minLines → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → InputDecorationEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited