RowEntity class

Constructors

RowEntity({required List<ColumnEntity> columns, List<CellEntity>? cells})
RowEntity.fromJson(Map<String, dynamic> jsonRes, List<ColumnEntity> columns)
factory

Properties

cells ↔ List<CellEntity>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFilled → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → RowEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited