StyleEntity class

Constructors

StyleEntity({FontWeight? fontWeight, double? fontSize, Color? fontColor, Color? backgroundColor, Alignment? horizontalAlignment, CrossAxisAlignment? verticalAlignment, TextAlign? textAlign})
const
StyleEntity.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

backgroundColor → Color?
final
fontColor → Color?
final
fontSize → double?
final
fontWeight → FontWeight?
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalAlignment → Alignment?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlign → TextAlign?
final
verticalAlignment → CrossAxisAlignment?
final

Methods

copy() → StyleEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited