TableEntity class

Constructors

TableEntity({int? columnCount, int? rowCount, bool addable = false, bool removable = false, CaptionLayoutEntity? captionLayout, required List<ColumnEntity> columns, required List<RowEntity> rows, FooterLayoutEntity? footerLayout})
const
TableEntity.fromJson(Map<String, dynamic> jsonRes)
factory

Properties

addable → bool
final
captionLayout → CaptionLayoutEntity?
final
columnCount → int?
final
columns → List<ColumnEntity>
final
footerLayout → FooterLayoutEntity?
final
hashCode → int
The hash code for this object.
no setterinherited
isFilled → bool
no setter
removable → bool
final
rowCount → int?
final
rows → List<RowEntity>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → TableEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override
updateAutoIncreaseColumn() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited