EditableTableCaption class

Inheritance

Constructors

EditableTableCaption({Key? key, required CaptionLayoutEntity captionLayoutEntity, required double captionWidth, Border? captionBorder, EdgeInsetsGeometry? captionPadding, TextStyle? captionTextStyle, TextStyle? captionHintTextStyle, EdgeInsetsGeometry? captionInputDecorationContentPadding, InputBorder? captionInputDecorationBorder, InputBorder? captionInputDecorationFocusBorder, AutovalidateMode? formFieldAutoValidateMode, bool readOnly = false, TableFiledFilled<String>? onFilling, TableFiledFilled<String>? onSubmitted})
const

Properties

captionBorder → Border?
final
captionHintTextStyle → TextStyle?
final
captionInputDecorationBorder → InputBorder?
final
captionInputDecorationContentPadding → EdgeInsetsGeometry?
final
captionInputDecorationFocusBorder → InputBorder?
final
captionLayoutEntity → CaptionLayoutEntity
final
captionPadding → EdgeInsetsGeometry?
final
captionTextStyle → TextStyle?
final
captionWidth → double
final
formFieldAutoValidateMode → AutovalidateMode?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onFilling → TableFiledFilled<String>?
final
onSubmitted → TableFiledFilled<String>?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _EditableTableCaptionState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited