EditableTableRow class

Inheritance

Constructors

EditableTableRow({Key? key, required RowEntity rowEntity, bool removable = false, required double rowWidth, Border? rowBorder, EdgeInsetsGeometry? cellContentPadding, EdgeInsetsGeometry? cellInputDecorationContentPadding, TextStyle? cellHintTextStyle, InputBorder? cellInputDecorationBorder, InputBorder? cellInputDecorationFocusBorder, TextStyle? cellTextStyle, Widget? removeRowIcon, EdgeInsetsGeometry? removeRowIconPadding, Alignment? removeRowIconAlignment, Color? removeRowIconContainerBackgroundColor, AutovalidateMode? formFieldAutoValidateMode, bool readOnly = false, ValueChanged<RowEntity>? onRowRemoved, TableFiledFilled? onFilling, TableFiledFilled? onSubmitted})
const

Properties

cellContentPadding → EdgeInsetsGeometry?
final
cellHintTextStyle → TextStyle?
final
cellInputDecorationBorder → InputBorder?
final
cellInputDecorationContentPadding → EdgeInsetsGeometry?
final
cellInputDecorationFocusBorder → InputBorder?
final
cellTextStyle → TextStyle?
final
formFieldAutoValidateMode → AutovalidateMode?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onFilling → TableFiledFilled?
final
onRowRemoved → ValueChanged<RowEntity>?
final
onSubmitted → TableFiledFilled?
final
readOnly → bool
final
removable → bool
final
removeRowIcon → Widget?
final
removeRowIconAlignment → Alignment?
final
removeRowIconContainerBackgroundColor → Color?
final
removeRowIconPadding → EdgeInsetsGeometry?
final
rowBorder → Border?
final
rowEntity → RowEntity
final
rowWidth → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _EditableTableRowState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited